svn commit: r324585 - stable/10/cddl/contrib/opensolaris/lib/libzfs/common

Andriy Gapon avg at FreeBSD.org
Fri Oct 13 09:07:59 UTC 2017


Author: avg
Date: Fri Oct 13 09:07:58 2017
New Revision: 324585
URL: https://svnweb.freebsd.org/changeset/base/324585

Log:
  MFC r323525: MFV r323523: 8331 zfs_unshare returns wrong error code for smb unshare failure

Modified:
  stable/10/cddl/contrib/opensolaris/lib/libzfs/common/libzfs_mount.c
Directory Properties:
  stable/10/   (props changed)

Modified: stable/10/cddl/contrib/opensolaris/lib/libzfs/common/libzfs_mount.c
==============================================================================
--- stable/10/cddl/contrib/opensolaris/lib/libzfs/common/libzfs_mount.c	Fri Oct 13 09:06:57 2017	(r324584)
+++ stable/10/cddl/contrib/opensolaris/lib/libzfs/common/libzfs_mount.c	Fri Oct 13 09:07:58 2017	(r324585)
@@ -24,6 +24,7 @@
  * Copyright (c) 2005, 2010, Oracle and/or its affiliates. All rights reserved.
  * Copyright (c) 2014 by Delphix. All rights reserved.
  * Copyright 2016 Igor Kozhukhov <ikozhukhov at gmail.com>
+ * Copyright 2017 RackTop Systems.
  */
 
 /*
@@ -88,7 +89,7 @@ zfs_share_type_t zfs_is_shared_proto(zfs_handle_t *, c
     zfs_share_proto_t);
 
 /*
  * The share protocols table must be in the same order as the zfs_share_prot_t
  * enum in libzfs_impl.h
  */
 typedef struct {
@@ -873,7 +874,7 @@ unshare_one(libzfs_handle_t *hdl, const char *name, co
 	/* make sure libshare initialized */
 	if ((err = zfs_init_libshare(hdl, SA_INIT_SHARE_API)) != SA_OK) {
 		free(mntpt);	/* don't need the copy anymore */
-		return (zfs_error_fmt(hdl, EZFS_UNSHARENFSFAILED,
+		return (zfs_error_fmt(hdl, proto_table[proto].p_unshare_err,
 		    dgettext(TEXT_DOMAIN, "cannot unshare '%s': %s"),
 		    name, _sa_errorstr(err)));
 	}
@@ -884,12 +885,13 @@ unshare_one(libzfs_handle_t *hdl, const char *name, co
 	if (share != NULL) {
 		err = zfs_sa_disable_share(share, proto_table[proto].p_name);
 		if (err != SA_OK) {
-			return (zfs_error_fmt(hdl, EZFS_UNSHARENFSFAILED,
+			return (zfs_error_fmt(hdl,
+			    proto_table[proto].p_unshare_err,
 			    dgettext(TEXT_DOMAIN, "cannot unshare '%s': %s"),
 			    name, _sa_errorstr(err)));
 		}
 	} else {
-		return (zfs_error_fmt(hdl, EZFS_UNSHARENFSFAILED,
+		return (zfs_error_fmt(hdl, proto_table[proto].p_unshare_err,
 		    dgettext(TEXT_DOMAIN, "cannot unshare '%s': not found"),
 		    name));
 	}
@@ -88,7 +89,7 @@ zfs_share_type_t zfs_is_shared_proto(zfs_handle_t *, c
 
 /*
- * The share protocols table must be in the same order as the zfs_share_prot_t
+ * The share protocols table must be in the same order as the zfs_share_proto_t
  * enum in libzfs_impl.h
  */


More information about the svn-src-all mailing list